<?php

namespace Hilmysyarif\Kegiatan\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Hilmysyarif\Kegiatan\Models\Kegiatan;

class KegiatanPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the kegiatan.
     *
     * @param User $user
     * @param Kegiatan $kegiatan
     *
     * @return bool
     */
    public function view(User $user, Kegiatan $kegiatan)
    {
        if ($user->canDo('kegiatan.kegiatan.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $kegiatan->user_id;
    }

    /**
     * Determine if the given user can create a kegiatan.
     *
     * @param User $user
     * @param Kegiatan $kegiatan
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('kegiatan.kegiatan.create');
    }

    /**
     * Determine if the given user can update the given kegiatan.
     *
     * @param User $user
     * @param Kegiatan $kegiatan
     *
     * @return bool
     */
    public function update(User $user, Kegiatan $kegiatan)
    {
        if ($user->canDo('kegiatan.kegiatan.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $kegiatan->user_id;
    }

    /**
     * Determine if the given user can delete the given kegiatan.
     *
     * @param User $user
     * @param Kegiatan $kegiatan
     *
     * @return bool
     */
    public function delete(User $user, Kegiatan $kegiatan)
    {
        if ($user->canDo('kegiatan.kegiatan.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $kegiatan->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
