<?php

namespace Hilmysyarif\Kegiatan\Providers;

use Illuminate\Support\ServiceProvider;

class KegiatanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'kegiatan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'kegiatan');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('kegiatan', function ($app) {
            return $this->app->make('Hilmysyarif\Kegiatan\Kegiatan');
        });

        // Bind Kegiatan to repository
        $this->app->bind(
            \Hilmysyarif\Kegiatan\Interfaces\KegiatanRepositoryInterface::class,
            \Hilmysyarif\Kegiatan\Repositories\Eloquent\KegiatanRepository::class
        );

        $this->app->register(\Hilmysyarif\Kegiatan\Providers\AuthServiceProvider::class);
        $this->app->register(\Hilmysyarif\Kegiatan\Providers\EventServiceProvider::class);
        $this->app->register(\Hilmysyarif\Kegiatan\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['kegiatan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/kegiatan.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__ . '/../../../../resources/views/public'  => base_path('resources/views/vendor/kegiatan/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views/admin' => base_path('resources/views/vendor/kegiatan/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/kegiatan')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
